@@ -29,7 +29,7 @@ zymkey.client.led_flash(500, 100)
 # Generate random blocks of 512 to fill a 1MB array
 bs = 512
 num_blocks = 256
-print('Generating random block ({!r} bytes)...'.format(bs * num_blocks))
+print('Generating random block from Zymkey ({!r} bytes)...'.format(bs * num_blocks))
 random_bytes = []
 for x in range(num_blocks):
     random_bytes += zymkey.client.get_random(bs)
