@@ -444,7 +444,9 @@ class Zymkey(object):
       # Get the type of the peer public key. If the type is 'int', peer_pubkey
       # refers to a slot internal to the zymkey. Otherwise, a list with the
       # contents of the public key is expected.
-      if type(peer_pubkey) == 'int':
+      if type(peer_pubkey) == 'int' or type(peer_pubkey) is int:
+         peer_pubkey = c_int(peer_pubkey)
+         peer_pubkey_slot_is_foreign = c_bool(peer_pubkey_slot_is_foreign)
          if kdf_func_type == "none":
             self._zkDoRawECDHWithIntPeerPubkey(self._zk_ctx, local_slot, peer_pubkey, peer_pubkey_slot_is_foreign, byref(derived_key))
             dst_data_sz = c_int(32)
@@ -758,7 +760,7 @@ class Zymkey(object):
    #  @param address The i2c address that the Zymkey will set itself
    #    to.
    def set_i2c_address(self, address):
-      addr_c_int = c_int()
+      addr_c_int = c_int(address)
       ret = self._zkSetI2CAddr(self._zk_ctx, addr_c_int)
       if ret < 0:
          raise AssertionError('bad return code %d' % ret)
